==> p6_cdk_github_oidc_provider-0.2.0.tar.gz: p6_cdk_github_oidc_provider-0.2.0/src/p6_cdk_github_oidc_provider/__init__.py <==
r'''
AWS CDK: Github OIDC Provider

# P6CDGithubOIDCProvider

## LICENSE

[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)

## Other

[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/p6m7g8/p6-cdk-github-oidc-provider) ![Sonarcloud Status](https://sonarcloud.io/api/project_badges/measure?project=p6m78_p6-cdk-github-oidc-provider&metric=alert_status) ![GitHub commit activity](https://img.shields.io/github/commit-activity/y/p6m7g8/p6-cdk-github-oidc-provider) ![GitHub commit activity](https://img.shields.io/github/commit-activity/m/p6m7g8/p6-cdk-github-oidc-provider)

## Usage

```python
...
import { P6CDKGithubOIDCProvider } from 'p6-cdk-github-oidc-provider';

new P6CDKGithubOIDCProvider(this, 'SiteNameGithubOIDCProvider', {
  repo: string
});
```

## Architecture

![./assets/diagram.png](./assets/diagram.png)

## Author

Philip M. Gollucci [pgollucci@p6m7g8.com](mailto:pgollucci@p6m7g8.com)
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
import constructs as _constructs_77d1e7e8


@jsii.interface(jsii_type="p6-cdk-github-oidc-provider.IP6CDKGithubOidcProviderProps")
class IP6CDKGithubOidcProviderProps(typing_extensions.Protocol):
    @builtins.property
    @jsii.member(jsii_name="repo")
    def repo(self) -> builtins.str:
        ...

    @builtins.property
    @jsii.member(jsii_name="policies")
    def policies(
        self,
    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]]:
        ...


class _IP6CDKGithubOidcProviderPropsProxy:
    __jsii_type__: typing.ClassVar[str] = "p6-cdk-github-oidc-provider.IP6CDKGithubOidcProviderProps"

    @builtins.property
    @jsii.member(jsii_name="repo")
    def repo(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "repo"))

    @builtins.property
    @jsii.member(jsii_name="policies")
    def policies(
        self,
    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]]:
        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]], jsii.get(self, "policies"))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IP6CDKGithubOidcProviderProps).__jsii_proxy_class__ = lambda : _IP6CDKGithubOidcProviderPropsProxy


class P6CDKGithubOidcProvider(
    _constructs_77d1e7e8.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="p6-cdk-github-oidc-provider.P6CDKGithubOidcProvider",
):
    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        props: IP6CDKGithubOidcProviderProps,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1607a19773e026a146fc9c3210b65b9ac90cf38815b3b550d561f32ab5c304e7)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        jsii.create(self.__class__, self, [scope, id, props])

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "roleArn"))


__all__ = [
    "IP6CDKGithubOidcProviderProps",
    "P6CDKGithubOidcProvider",
]

publication.publish()

def _typecheckingstub__1607a19773e026a146fc9c3210b65b9ac90cf38815b3b550d561f32ab5c304e7(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    props: IP6CDKGithubOidcProviderProps,
) -> None:
    """Type checking stubs"""
    pass

==> p6_cdk_github_oidc_provider-0.3.0.tar.gz: p6_cdk_github_oidc_provider-0.3.0/src/p6_cdk_github_oidc_provider/__init__.py <==
r'''
AWS CDK: Github OIDC Provider

# P6CDGithubOIDCProvider

## LICENSE

[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)

## Other

[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/p6m7g8/p6-cdk-github-oidc-provider) ![Sonarcloud Status](https://sonarcloud.io/api/project_badges/measure?project=p6m78_p6-cdk-github-oidc-provider&metric=alert_status) ![GitHub commit activity](https://img.shields.io/github/commit-activity/y/p6m7g8/p6-cdk-github-oidc-provider) ![GitHub commit activity](https://img.shields.io/github/commit-activity/m/p6m7g8/p6-cdk-github-oidc-provider)

## Usage

```python
...
import { P6CDKGithubOIDCProvider } from 'p6-cdk-github-oidc-provider';

new P6CDKGithubOIDCProvider(this, 'SiteNameGithubOIDCProvider', {
  repo: string
});
```

## Architecture

![./assets/diagram.png](./assets/diagram.png)

## Author

Philip M. Gollucci [pgollucci@p6m7g8.com](mailto:pgollucci@p6m7g8.com)
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import constructs as _constructs_77d1e7e8


class P6CDKGithubOidcProvider(
    _constructs_77d1e7e8.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="p6-cdk-github-oidc-provider.P6CDKGithubOidcProvider",
):
    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
        '''
        :param scope: -
        :param id: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1607a19773e026a146fc9c3210b65b9ac90cf38815b3b550d561f32ab5c304e7)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        jsii.create(self.__class__, self, [scope, id])


__all__ = [
    "P6CDKGithubOidcProvider",
]

publication.publish()

def _typecheckingstub__1607a19773e026a146fc9c3210b65b9ac90cf38815b3b550d561f32ab5c304e7(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass
